package cli

import (
	"os"

	"git.akyoto.dev/cli/q/build"
	"git.akyoto.dev/cli/q/log"
)

func Build(args []string) int {
	directory := "."

	if len(args) > 0 {
		directory = args[0]
	}

	stat, err := os.Stat(directory)

	if err != nil {
		log.Error.Println(err)
		return 1
	}

	if !stat.IsDir() {
		log.Error.Println("Build path must be a directory")
		return 2
	}

	b, err := build.New(directory)

	if err != nil {
		log.Error.Println(err)
		return 1
	}

	for i := 1; i < len(args); i++ {
		switch args[i] {
		case "--dry":
			b.WriteExecutable = false

		default:
			log.Error.Printf("Unknown parameter: %s\n", args[i])
			return 2
		}
	}

	err = b.Run()

	if err != nil {
		log.Error.Println(err)
		return 1
	}

	return 0
}
